==> V12.4.zip: cartreader/README.md <==
![image](https://dl.dropboxusercontent.com/s/ioc5oewzcuvs8nz/logos.png?dl=1)   

# Open Source Cartridge Reader
This project represents a community-driven effort to provide an easy to build and easy to modify cartridge dumper.     
Its main purpose is to dump a video game's ROM and save file to an SD card without the need of a PC.    

For any questions you can use the [Discussions](https://github.com/sanni/cartreader/discussions) and/or [Issues](https://github.com/sanni/cartreader/issues) section here on Github or visit the accompanying thread in the [Arduino Forum](http://forum.arduino.cc/index.php?topic=158974.9001), where you can reach most of the devs directly.    

Also be sure to check the guides in the [Wiki](https://github.com/sanni/cartreader/wiki) too.    

Happy making. 🔧🔨😊    

![image](https://dl.dropboxusercontent.com/s/3lrn7xh3f7h6jre/HW5_front.png?dl=1)   

#### Features:  
- Modular design   
- Stand-alone operation  
- Easy to modify open-source code      
- Portable when used together with a power bank  

![image](https://dl.dropboxusercontent.com/s/w99hewh6ors3awb/HW5_side.png?dl=1)   

#### Supported Systems:    
- NES/Famicom/Family Basic   
- SNES/Super Famicom (including SF Memory and Satellaview)  
- N64 (including Controller Pak and Gameshark)     
- Game Boy Color (including GB Memory)  
- Game Boy Advance    
- Sega Mega Drive/Genesis    
- Sega Master System   

![image](https://dl.dropboxusercontent.com/s/oi7c2radgblylyz/HW5_slots.png?dl=1)  

#### Supported with adapters:    
- Virtual Boy    
- Sega Game Gear    
- Sega Mark III     
- Sega SG-1000    
- Sega Cards    
- PC engine/TG16    
- WonderSwan (Color)    
- NeoGeo Pocket (Color)    
- Intellivision   
- ColecoVision    
- Benesse Pocket Challenge W    
- Benesse Pocket Challenge V2    
- Watara Supervision    
- Atari 2600    
- Emerson Arcadia 2001   
- Fairchild Channel F     
- Magnavox Odyssey 2  
- Super A'Can    

#### Open Source Licenses:    
- Software(everything in Cart_Reader folder) = GPL v3   
- Hardware(everything in hardware folder) = CC-BY-4.0

==> V13.1.zip: cartreader/README.md <==
![image](https://dl.dropboxusercontent.com/s/ioc5oewzcuvs8nz/logos.png?dl=1)   

# Open Source Cartridge Reader
This project represents a community-driven effort to provide an easy to build and easy to modify cartridge dumper.     
Its main purpose is to dump a video game's ROM and save file to an SD card without the need of a PC.    

For any questions you can use the [Discussions](https://github.com/sanni/cartreader/discussions) and/or [Issues](https://github.com/sanni/cartreader/issues) section here on Github or visit the accompanying thread in the [Arduino Forum](http://forum.arduino.cc/index.php?topic=158974.9001), where you can reach most of the devs directly.    

Also be sure to check the guides in the [Wiki](https://github.com/sanni/cartreader/wiki) too.    

Happy making. 🔧🔨😊    

![image](https://dl.dropboxusercontent.com/s/3lrn7xh3f7h6jre/HW5_front.png?dl=1)   

#### Features:  
- Modular design   
- Stand-alone operation  
- Easy to modify open-source code      
- Portable when used together with a power bank  

![image](https://dl.dropboxusercontent.com/s/w99hewh6ors3awb/HW5_side.png?dl=1)   

#### Supported Systems:    
- NES/Famicom/Family Basic   
- Super Nintendo/Super Famicom (including SF Memory and Satellaview)  
- Nintendo 64 (including Controller Pak, Gameshark, and Xplorer 64)  
- Game Boy Color (including GB Memory, Codebreaker, and Gameshark)  
- Game Boy Advance    
- Sega Mega Drive/Genesis    
- Sega Master System   

![image](https://dl.dropboxusercontent.com/s/oi7c2radgblylyz/HW5_slots.png?dl=1)  

#### Supported with adapters:    
- Virtual Boy    
- Sega Game Gear    
- Sega Mark III     
- Sega SG-1000/SC-3000    
- Sega Cards    
- PC engine/TurboGrafx-16    
- WonderSwan (Color)    
- NeoGeo Pocket (Color)    
- Intellivision   
- ColecoVision    
- Benesse Pocket Challenge W    
- Benesse Pocket Challenge V2    
- Watara Supervision    
- Atari 2600/5200/7800    
- Emerson Arcadia 2001   
- Fairchild Channel F     
- Magnavox Odyssey 2/Philips Videopac+  
- Super A'Can    
- MSX    
- Pokémon Mini     
- Casio Loopy
- Commodore 64    
- Vectrex    

#### Open Source Licenses:    
- Software(everything in Cart_Reader folder) = GPL v3   
- Hardware(everything in hardware folder) = CC BY 4.0   
- Documentation(everything in the Wiki) = CC0 1.0
